# Welcome to the Random-Events Documentation

This documentation is intended to provide a comprehensive guide to the Random-Events 
package. The package is designed to provide a simple and flexible way to generate 
events that are suitable for probabilistic reasoning in a python.

## Citing random_events

If you use this software, please cite it as below.

```bibtex
@software{schierenbeck2024re,
author = {Schierenbeck, Tom},
title = {Random-Events},
url = {https://github.com/tomsch420/random-events},
version = {3.0.6},
}
```


```{tableofcontents}
```